@@ -69,7 +69,7 @@ $smarty->assign('input_template',
 $smarty->assign('dflt_image','');
 $smarty->assign('dflt_url','');
 
-$module =& $this->_getUploadsModule();
+$module = $this->_getUploadsModule();
 if( $module )
   {
     $categorylist = $module->getCategoryList();
