@@ -58,7 +58,7 @@ if (isset ($params['cancel']))
     else
       {
 	// check if the category doesn't already exist
-	$db =& $this->GetDb();
+	$db = $this->GetDb();
 	$query =
 	  "SELECT * from ".cms_db_prefix ().
 	  "module_banners_categories WHERE name = ?";
