@@ -37,7 +37,7 @@
 
 function _DisplayCategoriesTab( &$module, $id, &$params, $returnid )
 {
-  $db =& $module->GetDb();
+  $db = $module->GetDb();
   $rowarray = array();
   $dbresult = '';
   
