@@ -1,4 +1,15 @@
 <?php
+$lang['statreport_linesperpage'] = 'Linjer per side i statistikkrapporten';
+$lang['banner'] = 'Banner annonse';
+$lang['of'] = 'av';
+$lang['page'] = 'Side';
+$lang['generated'] = 'Generert';
+$lang['generated_by'] = 'Generert av';
+$lang['desc_stats_report'] = 'En rapport som illustrerer antall visninger og klikk-via treff fra Banners modulen';
+$lang['title_stats_report'] = 'Banner statistikkrapport';
+$lang['view_statistics'] = 'Vis statistikk';
+$lang['msg_new_window'] = 'Lager et nytt vindu';
+$lang['statreport_template'] = 'Statistikk rapportmal';
 $lang['your_ad_here'] = 'Din annonse kunne v&aelig;rt her';
 $lang['prompt_dflt_image'] = 'Standard bilde';
 $lang['prompt_dflt_url'] = 'Standard URL';
@@ -123,9 +134,9 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 Or read it <a href="http://www.gnu.org/licenses/licenses.html#GPL">online</a></p>';
-$lang['utmz'] = '156861353.1296948797.3555.80.utmcsr=feedburner|utmccn=Feed: cmsmadesimple/blog (CMS Made Simple)|utmcmd=feed';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1297627188.1297629005.3583';
+$lang['utmz'] = '156861353.1300226369.3692.81.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/feature_request/list/6';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1301237988.1301251141.3715';
 $lang['qca'] = '1210971690-27308073-81952832';
+$lang['utmb'] = '156861353.1.10.1301251141';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.3.10.1297629005';
 ?>
\ No newline at end of file
